/******************************************************************************
*
* project name: TI-MineSweeper
* filename:     counter.c
* initial date: 03/07/2000
* authors:      thomas.nussbaumer@gmx.net (coding)
*               marcos.lopez@wol.es (game play/graphics/BETA testing)
* description:  handling of a 3 digit counter with width=6 and height=15
*
* IMPORTANT: graymode must be already on before calling InitCounter()
*
* !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
* NOTE:  depends on TIGCC Standard Library 2.1 to compile
* NOTE2: TIGCC Standard Library 2.0 contains a major bug in the sprite drawing
*        routines. Therefore don't compile TI-Con45 with Library 2.0 !!
* !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
*
* -----------------------------------------------------------------------------
* Revision History
* -----------------------------------------------------------------------------
*
* v1.00: 03/07/2000
*        initial version
*
*******************************************************************************/

#ifndef _COUNTER_C_
#define _COUNTER_C_

#include <sprites.h>
#include <gray.h>

#define NUMBER_HEIGHT  15
#define NUMBER_WIDTH    6
#define NUMBER_OFFSET  15

//-------------------------------
// structure describing a counter
//-------------------------------
typedef struct {
    int xpos;         // x position of counter
    int ypos;         // y position of counter
    int value;        // active value of counter
    int digits[3];    // internally used
} counter_t;

unsigned char numbers_plane1[15*10]={
0xfe,0xc6,0xba,0xba,0xba,0xba,0xba,0xfe,0xba,0xba,0xba,0xba,0xba,0xc6,0xfe, //0
0xfe,0xfe,0xfa,0xfa,0xfa,0xfa,0xfa,0xfe,0xfa,0xfa,0xfa,0xfa,0xfa,0xfe,0xfe, //1
0xfe,0xc6,0xfa,0xfa,0xfa,0xfa,0xfa,0xc6,0xbe,0xbe,0xbe,0xbe,0xbe,0xc6,0xfe, //2
0xfe,0xc6,0xfa,0xfa,0xfa,0xfa,0xfa,0xc6,0xfa,0xfa,0xfa,0xfa,0xfa,0xc6,0xfe, //3
0xfe,0xfe,0xba,0xba,0xba,0xba,0xba,0xc6,0xfa,0xfa,0xfa,0xfa,0xfa,0xfe,0xfe, //4
0xfe,0xc6,0xbe,0xbe,0xbe,0xbe,0xbe,0xc6,0xfa,0xfa,0xfa,0xfa,0xfa,0xc6,0xfe, //5
0xfe,0xc6,0xbe,0xbe,0xbe,0xbe,0xbe,0xc6,0xba,0xba,0xba,0xba,0xba,0xc6,0xfe, //6
0xfe,0xc6,0xfa,0xfa,0xfa,0xfa,0xfa,0xfe,0xfa,0xfa,0xfa,0xfa,0xfa,0xfe,0xfe, //7
0xfe,0xc6,0xba,0xba,0xba,0xba,0xba,0xc6,0xba,0xba,0xba,0xba,0xba,0xc6,0xfe, //8
0xfe,0xc6,0xba,0xba,0xba,0xba,0xba,0xc6,0xfa,0xfa,0xfa,0xfa,0xfa,0xc6,0xfe};//9

unsigned char numbers_plane2[15*10]={
0xfe,0xc6,0xba,0xba,0xba,0xba,0xba,0xfe,0xba,0xba,0xba,0xba,0xba,0xc6,0xfe, //0
0xfe,0xfe,0xfa,0xfa,0xfa,0xfa,0xfa,0xfe,0xfa,0xfa,0xfa,0xfa,0xfa,0xfe,0xfe, //1
0xfe,0xc6,0xfa,0xfa,0xfa,0xfa,0xfa,0xc6,0xbe,0xbe,0xbe,0xbe,0xbe,0xc6,0xfe, //2
0xfe,0xc6,0xfa,0xfa,0xfa,0xfa,0xfa,0xc6,0xfa,0xfa,0xfa,0xfa,0xfa,0xc6,0xfe, //3
0xfe,0xfe,0xba,0xba,0xba,0xba,0xba,0xc6,0xfa,0xfa,0xfa,0xfa,0xfa,0xfe,0xfe, //4
0xfe,0xc6,0xbe,0xbe,0xbe,0xbe,0xbe,0xc6,0xfa,0xfa,0xfa,0xfa,0xfa,0xc6,0xfe, //5
0xfe,0xc6,0xbe,0xbe,0xbe,0xbe,0xbe,0xc6,0xba,0xba,0xba,0xba,0xba,0xc6,0xfe, //6
0xfe,0xc6,0xfa,0xfa,0xfa,0xfa,0xfa,0xfe,0xfa,0xfa,0xfa,0xfa,0xfa,0xfe,0xfe, //7
0xfe,0xc6,0xba,0xba,0xba,0xba,0xba,0xc6,0xba,0xba,0xba,0xba,0xba,0xc6,0xfe, //8
0xfe,0xc6,0xba,0xba,0xba,0xba,0xba,0xc6,0xfa,0xfa,0xfa,0xfa,0xfa,0xc6,0xfe};//9

unsigned char cleaner[15] = {
0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01};


unsigned char* used_plane1 = 0;
unsigned char* used_plane2 = 0;

unsigned int firsttime = 1;

/*===========================================================================*/
/* updates counter display                                                   */
/*===========================================================================*/
void UpdateCounter(counter_t *p) {
    int tmp[3];
    int value = p->value;
    int i;

    if (value > 999) value = 999;
    if (value < 0)   value = 0;

    for (i=2;i>=0;i--) {
        tmp[i] = value % 10;
        value /= 10;
    }

    for (i=0;i<3;i++) {
        if (firsttime || tmp[i] != p->digits[i]) {
            int real_x       = p->xpos + i*NUMBER_WIDTH;
            int digit_offset = NUMBER_OFFSET*tmp[i];
            Sprite8(real_x,
                    p->ypos,
                    NUMBER_HEIGHT,
                    cleaner,
                    used_plane1,
                    SPRT_AND);
            Sprite8(real_x,
                    p->ypos,NUMBER_HEIGHT,
                    cleaner,
                    used_plane2,
                    SPRT_AND);
            Sprite8(real_x,
                    p->ypos,
                    NUMBER_HEIGHT,
                    numbers_plane1+digit_offset,
                    used_plane1,
                    SPRT_OR);
            Sprite8(real_x,
                    p->ypos,
                    NUMBER_HEIGHT,
                    numbers_plane2+digit_offset,
                    used_plane2,
                    SPRT_OR);
            p->digits[i] = tmp[i];
        }
    }

    firsttime = 0;
 }


/*===========================================================================*/
/* initialize counter (NOTE: counter structure must be setup already)        */
/*===========================================================================*/
void InitCounter(counter_t* p) {
    firsttime = 1;
    used_plane1 = GetPlane(0);
    used_plane2 = GetPlane(1);
    UpdateCounter(p);
}

#endif

