/******************************************************************************
*
* project name: TI-MineSweeper v1.00
* filename:     titles.c
* initial date: 04/07/2000
* authors:      thomas.nussbaumer@gmx.net (coding)
*               marcos.lopez@wol.es (game play/graphics/BETA testing)
* description:  tiles data and output routines
*
* IMPORTANT: graymode must be already on before calling OutputTile
*
* !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
* NOTE:  depends on TIGCC Standard Library 2.1 to compile
* NOTE2: TIGCC Standard Library 2.0 contains a major bug in the sprite drawing
*        routines. Therefore don't compile TI-Con45 with Library 2.0 !!
* !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
*
* -----------------------------------------------------------------------------
* Revision History
* -----------------------------------------------------------------------------
*
* v1.00: 04/07/2000
*        initial version
*
*******************************************************************************/

#define TYPE_UNDISCOVERED   0
#define TYPE_MARKED         8
#define TYPE_INTERROGATION 16
#define TYPE_WRONGMARK     24
#define TYPE_MINE          32
#define TYPE_CLICKEDMINE   40

extern unsigned char* plane1;
extern unsigned char* plane2;
extern unsigned int   tiles_offset_x;
extern unsigned int   tiles_offset_y;

/*
unsigned char count_tiles1[]={
0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,  //no mines near
0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,  //one mine near
0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,  //two mines near
0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,  //three mines near
0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,  //four mines near
0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,  //five mines near
0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,  //six mines near
0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,  //seven mines near
0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff}; //eight mines near
*/
/*
unsigned char count_tiles1[]={
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,  //no mines near
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,  //one mine near
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,  //two mines near
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,  //three mines near
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,  //four mines near
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,  //five mines near
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,  //six mines near
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,  //seven mines near
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00}; //eight mines near
*/

// using count_tiles2 for both planes
unsigned char count_tiles2[]={
0x00,0x01,0x00,0x01,0x00,0x01,0x00,0x55,  //no mines near
0x00,0x11,0x30,0x11,0x10,0x39,0x00,0x55,  //one mine near
0x00,0x31,0x08,0x11,0x20,0x39,0x00,0x55,  //two mines near
0x00,0x31,0x08,0x11,0x08,0x31,0x00,0x55,  //three mines near
0x00,0x21,0x28,0x39,0x08,0x09,0x00,0x55,  //four mines near
0x00,0x39,0x20,0x31,0x08,0x31,0x00,0x55,  //five mines near
0x00,0x19,0x20,0x39,0x28,0x39,0x00,0x55,  //six mines near
0x00,0x39,0x08,0x11,0x20,0x21,0x00,0x55,  //seven mines near
0x00,0x39,0x28,0x39,0x28,0x39,0x00,0x55}; //eight mines near

unsigned char misc_tiles1[] = {
0x01,0x7d,0x7d,0x7d,0x7d,0x7d,0x01,0xff,  //undiscovered
0x01,0x45,0x4d,0x7d,0x7d,0x7d,0x01,0xff,  //flag
0x01,0x7d,0x7d,0x7d,0x7d,0x7d,0x01,0xff,  //interrogation
0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,  //wrongly marked
0xff,0xff,0xff,0xef,0xff,0xff,0xff,0xff,  //mine
0x00,0x39,0x7c,0x6d,0x7c,0x39,0x00,0x55}; //clicked mine

unsigned char misc_tiles2[]={
0x01,0x03,0x03,0x03,0x03,0x03,0x7f,0xff,  //undiscovered
0x01,0x3b,0x3b,0x0b,0x0b,0x1f,0x7f,0xff,  //flag
0x01,0x33,0x0b,0x13,0x03,0x13,0x7f,0xff,  //interrogation
0x00,0x45,0x28,0x11,0x28,0x45,0x00,0x55,  //wrongly marked
0x00,0x39,0x7c,0x6d,0x7c,0x39,0x00,0x55,  //mine
0xff,0xff,0xff,0xef,0xff,0xff,0xff,0xff}; //clicked mine

unsigned char tiles_cleaner[]={
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00};


/*===========================================================================*/
/* output single tile at position (x/y)                                      */
/*===========================================================================*/
void OutputTile(unsigned char* src1, unsigned char* src2, int x, int y) {
    x *= 8;
    x += tiles_offset_x;
    y *= 8;
    y += tiles_offset_y;

    Sprite8(x,y,8,tiles_cleaner,plane1,SPRT_AND);
    Sprite8(x,y,8,tiles_cleaner,plane2,SPRT_AND);
    Sprite8(x,y,8,src1,plane1,SPRT_OR);
    Sprite8(x,y,8,src2,plane2,SPRT_OR);
}

/*===========================================================================*/
/* output a count tile for given count at position (x/y)                     */
/*===========================================================================*/
void OutputCountTile(int count, int x,int y) {
    count *= 8;
    // NOTE: using count_tiles2 for both planes to get more contrast !!!
    OutputTile(count_tiles2+count,count_tiles2+count,x,y);
}

/*===========================================================================*/
/* output a misc tile of given type at position (x/y)                        */
/*===========================================================================*/
void OutputMiscTile(int type, int x,int y) {
    OutputTile(misc_tiles1+type,misc_tiles2+type,x,y);
}

